# Streamlit-ipyvizzu

[![Open in Streamlit](https://static.streamlit.io/badges/streamlit_badge_black_white.svg)](https://avrabyt-streamlit-ipyvizzu-app-f69fjd.streamlitapp.com)


#### Implementing [ipyvizzu](https://github.com/vizzuhq/ipyvizzu) within Streamlit App as a Demo 🎈🎉

## Animated charts ✨
![Animation](https://github.com/avrabyt/Streamlit-ipyvizzu/blob/main/Resources/animation.gif)

## Story-presentation ⌛️
![Animation](https://github.com/avrabyt/Streamlit-ipyvizzu/blob/main/Resources/story.gif)
